<?php
/**
 * Plugin Name: WP Custom HTML Pages
 * Plugin URI: https://witserbia.com/wordpress-plugins/wp-custom-html-pages/
 * Description: Display full custom HTML on custom permalink address, or put it inside content as a shortcode
 * Version: 0.4.4
 * Author: Milos Stojanovic
 * License: GPL2
 * License URI: https://www.gnu.org/licenses/gpl-2.0.html
 *
 */


// Copyright (c), Milos Stojanovic

/*
WP Custom HTML Pages is free software: you can redistribute it and/or modify it 
under the terms of the GNU General Public License as published by the Free Software Foundation, 
either version 2 of the License, or any later version.

WP Custom HTML Pages is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; 
without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. 
See the GNU General Public License for more details.

You should have received a copy of the GNU General Public License along with WP Custom HTML Pages. 
If not, see https://www.gnu.org/licenses/gpl-2.0.html .
*/
 
// Make sure we don't expose any info if called directly
if ( !function_exists( 'add_action' ) ) {
	echo 'Direct access not allowed.';
	exit;
}



register_activation_hook( __FILE__, 'WPCHTMLP_install' );
register_activation_hook( __FILE__, 'WPCHTMLP_install_data' );

function WPCHTMLP_install() {
    global $wpdb;

   $table_name = $wpdb->prefix . "wpchtmlp_pages"; 

    $charset_collate = $wpdb->get_charset_collate();

$sql = "CREATE TABLE $table_name (
  post_id mediumint(9) NOT NULL,
  time datetime DEFAULT '0000-00-00 00:00:00' NOT NULL,
  name tinytext NOT NULL,
  html text NOT NULL,
  url varchar(55) DEFAULT '' NOT NULL,
  UNIQUE KEY  (post_id)
) $charset_collate;";

    require_once( ABSPATH . 'wp-admin/includes/upgrade.php' );
    dbDelta( $sql );
   
}

function WPCHTMLP_install_data() {
    global $wpdb;
    
    $example_name = 'Mr. WordPress';
    $example_html = '<!DOCTYPE html><html><head><title>WP Custom HTML Pages plugin example page</title></head><body style="text-align:center;"><h1>Welcome to the example page of WP Custom HTML Pages plugin</h1><br><br><a href="https://witserbia.com/wordpress-plugins/wp-custom-html-page/">Plugin link</a></body></html>';
    $example_url = 'wp-custom-html-page-example';
    
    $table_name = $wpdb->prefix . 'wpchtmlp_pages';
    $wpdb->show_errors();
    $wpdb->insert( 
        $table_name, 
        array( 
            'post_id' => 0,
            'time' => current_time( 'mysql' ), 
            'name' => $example_name, 
            'html' => $example_html, 
            'url' => $example_url
        ) 
    );
}


add_action('admin_enqueue_scripts', 'WPCHTMLP_include_scripts');

function WPCHTMLP_include_scripts() {
    wp_register_style( 'wpchtmlp_style', plugins_url('css/style.css',__FILE__ ) );
    wp_enqueue_style( 'wpchtmlp_style' );
    
    if( get_option('wpchtmlp_opt_editor_type') != 2 ) {
        wp_register_script( 'wpchtmlp_script_ace', plugins_url('include/ace-builds-master/src-min-noconflict/ace.js',__FILE__ ));
        wp_enqueue_script('wpchtmlp_script_ace');
    }
}


function WPCHTMLP_page_post_type()
{
    register_post_type('wpchtmlp_page',
                       [
                           'labels'      => [
                               'name'          => __('HTML Pages'),
                               'singular_name' => __('HTML Page'),
                           ],
                           'public'      => true,
                           'has_archive' => true,
                           'rewrite'     => ['slug' => 'html-pages'],
                           'show_in_menu'   => 'edit.php?post_type=page',
                           'supports'   => ['title']
                       ]
    );
}
add_action('init', 'WPCHTMLP_page_post_type');

function WPCHTMLP_page_meta_box() {
	add_meta_box(
		'WPCHTMLP_page_meta_box', // $id
		'Page Settings', // $title
		'WPCHTMLP_page_meta_box_show', // $callback
		'wpchtmlp_page', // $screen
		'normal', // $context
		'high' // $priority
	);
}
add_action( 'add_meta_boxes', 'WPCHTMLP_page_meta_box' );
function WPCHTMLP_page_meta_box_show() {
	global $post;  
		$meta = get_post_meta( $post->ID, 'WPCHTMLP_page_meta_box', true ); ?>

	<input type="hidden" name="WPCHTMLP_page_meta_nonce" value="<?php echo wp_create_nonce( basename(__FILE__) ); ?>">

    <!-- WPCHTMLP fields -->
    
    <p>
	<label for="WPCHTMLP_page_meta_box[html_permalink]">Page Permalink (yourwebsite.com/page-permalink will link to the raw HTML page)</label>
	<br>
	<span><?php echo get_site_url()."/";?></span><input type="text" name="WPCHTMLP_page_meta_box[html_permalink]" id="WPCHTMLP_page_meta_box[html_permalink]" class="regular-text" value="<?php echo (isset($meta['html_permalink'])?$meta['html_permalink']:"enter-permalink-here"); ?>">
    </p>
    
    <p>
	<label for="WPCHTMLP_page_meta_box[html_code]">HTML Page Code</label>
	<br>
	<textarea name="WPCHTMLP_page_meta_box[html_code]" id="WPCHTMLP_page_meta_box[html_code]" rows="30" cols="90" style="width:1000px;<?php if( get_option('wpchtmlp_opt_editor_type') != 2 ) {?>display:none;<?php } ?>"><?php if(isset($meta['html_code'])) echo $meta['html_code']; ?>
<?php if(!isset($meta['html_code'])) {?>
 <!DOCTYPE html>
 <html>
 <head>
 <title>Page Title</title>
 <style type="text/css"></style>
 </head>
 <body>
 </body>
 </html>
<?php } ?></textarea>
    

    
    <?php if( get_option('wpchtmlp_opt_editor_type') != 2 ) {?>
    <div id="wpchtmlp_ace_editor"></div>
    <script>
        var wpchtmlp_ace_editor = ace.edit("wpchtmlp_ace_editor");
        wpchtmlp_ace_editor.setTheme("ace/theme/twilight");
        wpchtmlp_ace_editor.getSession().setMode("ace/mode/html");
        wpchtmlp_ace_editor.getSession().setValue(jQuery("#WPCHTMLP_page_meta_box\\[html_code\\]").text());
        //jQuery('#wpchtmlp_ace_editor').resizable();
        //jQuery('#wpchtmlp_ace_editor').on("resize", function() { wpchtmlp_ace_editor.resize() }); 
        wpchtmlp_ace_editor.getSession().on("change", function () {
            jQuery("#WPCHTMLP_page_meta_box\\[html_code\\]").val(wpchtmlp_ace_editor.getSession().getValue());
        });
    </script>
    <?php } ?>

    </p>
    

    
    
    <br>
    <p>
    <ul>
    <?php 
    echo ($meta['html_permalink']?"<li><strong>Direct link to raw HTML page: </strong> ".get_site_url()."/".$meta['html_permalink']."</li>":"");
    echo "<li><strong>Shortcode:</strong> [wpchtmlp id=".$post->ID."]</li>";
    ?>
    </ul>
    </p>
    
<?php }

function WPCHTMLP_page_meta_box_save( $post_id ) {   
	// verify nonce
	if ( !wp_verify_nonce( $_POST['WPCHTMLP_page_meta_nonce'], basename(__FILE__) ) ) {
		return $post_id; 
	}
	// check autosave
	if ( defined( 'DOING_AUTOSAVE' ) && DOING_AUTOSAVE ) {
		return $post_id;
	}
	// check permissions
	if ( 'page' === $_POST['wpchtmlp_page'] ) {
		if ( !current_user_can( 'edit_page', $post_id ) ) {
			return $post_id;
		} elseif ( !current_user_can( 'edit_post', $post_id ) ) {
			return $post_id;
		}  
	}
	
	$old = get_post_meta( $post_id, 'WPCHTMLP_page_meta_box', true );
	$new = $_POST['WPCHTMLP_page_meta_box'];
    
    if(!$old) {
        //brand new. use insert
        global $wpdb;
        $table_name = $wpdb->prefix . 'wpchtmlp_pages';
        $wpdb->show_errors();
        $wpdb->insert( 
            $table_name, 
            array( 
                'post_id' => $post_id,
                'time' => current_time( 'mysql' ), 
                'name' => get_the_title( $post_id ), 
                'html' => $new['html_code'], 
                'url' => $new['html_permalink']
            ) 
        );
    }
    
	if ( $new && $new !== $old ) {
		update_post_meta( $post_id, 'WPCHTMLP_page_meta_box', $new );
        
        //now the database part
        if($old) {
            global $wpdb;
            $table_name = $wpdb->prefix . 'wpchtmlp_pages';
            $wpdb->show_errors();
            $wpdb->update( 
                $table_name, 
                array( 
                    'time' => current_time( 'mysql' ), 
                    'name' => get_the_title( $post_id ), 
                    'html' => $new['html_code'], 
                    'url' => $new['html_permalink']
                ),
                array('post_id'=>$post_id)
            );
        }
        
	} elseif ( '' === $new && $old ) {
		delete_post_meta( $post_id, 'WPCHTMLP_page_meta_box', $old );
	}
}
add_action( 'save_post', 'WPCHTMLP_page_meta_box_save' );    

add_action( 'before_delete_post', 'WPCHTMLP_page_before_delete' );
function WPCHTMLP_page_before_delete( $post_id ){

    global $post_type;   
    if ( $post_type != 'wpchtmlp_page' ) return;
    
    global $wpdb;
    $table_name = $wpdb->prefix . 'wpchtmlp_pages';
    $wpdb->delete( 
        $table_name, 
        array('post_id'=>$post_id)
    );
}

// template file for reading page within Wordpress templating system
add_filter('single_template', 'WPCHTMLP_page_template', 999);

function WPCHTMLP_page_template($single) {

    global $wp_query, $post;

    /* Checks for single template by post type */
    if ( $post->post_type == 'wpchtmlp_page' ) {
        if ( file_exists( PLUGIN_PATH . '/single-wpchtmlp_page.php' ) ) {
            return PLUGIN_PATH . '/single-wpchtmlp_page.php';
        }
    }

    return $single;

}


add_action('parse_request', 'WPCHTMLP_permalink_handler');
function WPCHTMLP_permalink_handler() {
    
    $query_uri = esc_url($_SERVER["REQUEST_URI"]);
    if($query_uri[0]=="/")  $query_uri = substr($query_uri, 1);
    
    if($query_uri=="wp-admin" && !get_option('wpchtmlp_opt_allow_wp-admin'))
        return;
    
    global $wpdb;
    $table_name = $wpdb->prefix . 'wpchtmlp_pages';
    $results = $wpdb->get_results( 
        $wpdb->prepare("SELECT * FROM `".$table_name."` WHERE `url`=%s", $query_uri), ARRAY_A
     );
     
     if(count($results)>0) {
       if(get_post_status( $results[0]['post_id'] ) == 'publish') {
         echo stripslashes($results[0]['html']);
         exit;
       }
       
     }
     
}

add_shortcode('wpchtmlp', 'WPCHTMLP_shortcode_handler');

function WPCHTMLP_shortcode_handler($atts = [], $content = null, $tag = '') {
    $atts = array_change_key_case((array)$atts, CASE_LOWER);
    $id = $atts['id'];
    
    global $wpdb;
    $table_name = $wpdb->prefix . 'wpchtmlp_pages';
    $results = $wpdb->get_results( 
        $wpdb->prepare("SELECT * FROM `".$table_name."` WHERE `post_id`=%s", $id), ARRAY_A
     );
     
     if(count($results)>0) {
       if(get_post_status( $results[0]['post_id'] ) == 'publish') {
         $retStr = $results[0]['html'];
       }
     }
    
    return $retStr;
}


add_action( 'admin_init', 'WPCHTMLP_admin_init' );

function WPCHTMLP_admin_init() {
    register_setting( 'wpchtmlp-options', 'wpchtmlp_opt_editor_type' );
    register_setting( 'wpchtmlp-options', 'wpchtmlp_opt_editor_style' );
    register_setting( 'wpchtmlp-options', 'wpchtmlp_opt_allow_wp-admin' );
    register_setting( 'wpchtmlp-options', 'wpchtmlp_opt_remove_table_on_uninstall' );
}


add_action( 'admin_menu', 'WPCHTMLP_menu' );

function WPCHTMLP_menu() {
	add_options_page( 'WP Custom HTML Pages Options', 'WP Custom HTML Pages', 'manage_options', 'wpchtmlp-menu-identifier', 'WPCHTMLP_menu_options' );
}

function WPCHTMLP_menu_options() {
	if ( !current_user_can( 'manage_options' ) )  {
		wp_die( __( 'You do not have sufficient permissions to access this page.' ) );
	}
	echo '<div class="wrap">';
    echo '<h2>WP Custom HTML Pages Plugin Options</h2>';
	echo '<p>To add and work with custom HTML pages go to Pages->HTML Pages screen found in admin side menu.</p>';
    echo '<p>Custom URI and shortcode info is found on HTML page edit screen.</p>';
    echo '<p>To report plugin problems or submit feature requests <a href="https://witserbia.com/wordpress-plugins/wp-custom-html-pages/" target="_blank">go here</a>.</p>';
    echo '<p>Like the plugin? You can give it a good review or <a href="https://witserbia.com/wordpress-plugins/wp-custom-html-pages/" target="_blank">donate</a>.</p>';
    echo '<form method="post" action="options.php"> ';
    settings_fields( 'wpchtmlp-options' );
    do_settings_sections( 'wpchtmlp-options' );
    
    echo '<table class="form-table">
    
        <tr valign="top">
        <th><td><h3>Editor Options</h3></td></th>
        </tr>
        
        <tr valign="top">
        <th scope="row">Editor Type</th>
        <td>
        <input type="radio" name="wpchtmlp_opt_editor_type" value="1" '.checked(1, get_option('wpchtmlp_opt_editor_type'), true).'>ACE Editor&nbsp;&nbsp;
        <input type="radio" name="wpchtmlp_opt_editor_type" value="2" '.checked(2, get_option('wpchtmlp_opt_editor_type'), true).'>Textarea&nbsp;&nbsp;
        <span>&nbsp;&nbsp;Ace editor has syntax highlighting and error checking for HTML, CSS and JavaScript. Textarea is a common multirow input field.</span></td>
        </tr>
        
        <tr valign="top">
        <th><td><h3>Safety Options</h3></td></th>
        </tr>
        
        <tr valign="top">
        <th scope="row">Allow custom URI to be set as /wp-admin</th>
        <td><input type="checkbox" name="wpchtmlp_opt_allow_wp-admin" id="wpchtmlp_opt_allow_wp-admin" value="1" '.checked(get_option('wpchtmlp_opt_allow_wp-admin'),1).' />
        <span>&nbsp;&nbsp;Leave this OFF to prevent accidently locking yourself out of admin section. If you know what you are doing and wish to disable the admin login set it to ON.</span></td>
        </tr>
         
        <tr valign="top">
        <th><td><h3>Uninstallation Options</h3></td></th>
        </tr>
         
        <tr valign="top">
        <th scope="row">Completely remove WP Custom HTML Pages database table on uninstall</th>
        <td><input type="checkbox" name="wpchtmlp_opt_remove_table_on_uninstall" id="wpchtmlp_opt_remove_table_on_uninstall" value="1" '.checked(get_option('wpchtmlp_opt_remove_table_on_uninstall'),1).' />
        <span>&nbsp;&nbsp;If you check this ON, the database table used for mapping HTML pages to custom URI will be completely removed after uninstalling plugin. Set to ON only if you plan to never use this plugin again as all the custom URIs will permanently stopped working.</span></td>
        </tr>
    </table>';
    
    submit_button();
    echo '</form>';
	echo '</div>';
}


